# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]
- No unreleased changes so far

## [0.1] - 2025-01-25
Initial release, let's go and give this to the public to try out...

[unreleased]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/compare/v0.1...HEAD

[0.1]: https://github.com/tillsteinbach/CarConnectivity-plugin-homekit/releases/tag/v0.1
